pub(crate) enum ChildContainer {
DefWithBodyId(DefWithBodyId),
ModuleId(ModuleId),
TraitId(TraitId),
ImplId(ImplId),
EnumId(EnumId),
VariantId(VariantId),
GenericDefId(GenericDefId),
}Variants
DefWithBodyId(DefWithBodyId)
ModuleId(ModuleId)
TraitId(TraitId)
ImplId(ImplId)
EnumId(EnumId)
VariantId(VariantId)
GenericDefId(GenericDefId)
XXX: this might be the same def as, for example an EnumId. However,
here the children are generic parameters, and not, eg enum variants.
Implementations
Sourceimpl ChildContainer
impl ChildContainer
fn child_by_source(self, db: &dyn HirDatabase, file_id: HirFileId) -> DynMap
pub(crate) fn as_expression_store_owner(self) -> Option<ExpressionStoreOwnerId>